raytraverse.scene
==========================================================

BaseScene
-----------------------

.. autoclass:: raytraverse.scene.BaseScene
    :members:
    :undoc-members:
    :show-inheritance:


Scene
-----------------------

.. autoclass:: raytraverse.scene.Scene
    :members:
    :undoc-members:
    :show-inheritance:

ImageScene
-----------------------

.. autoclass:: raytraverse.scene.ImageScene
    :members:
    :undoc-members:
    :show-inheritance:
